@@ -22,7 +22,7 @@ package MongoDB;
 # ABSTRACT: Official MongoDB Driver for Perl
 
 use version;
-our $VERSION = 'v1.1.1'; # TRIAL
+our $VERSION = 'v1.3.0'; # TRIAL
 
 # regexp_pattern was unavailable before 5.10, had to be exported to load the
 # function implementation on 5.10, and was automatically available in 5.10.1
@@ -106,12 +106,11 @@ MongoDB - Official MongoDB Driver for Perl
 
 =head1 VERSION
 
-version v1.1.1
+version v1.3.0
 
-B<NOTE:> The v1.1.x versions are development releases in advance of the
-MongoDB Perl Driver v1.2.0. They are available for evaluation and testing
-and should not be used in production.  Most notably, they include support
-for features in MongoDB 3.2 release candidates.
+B<NOTE:> The v1.3.x versions are development releases in advance of the
+MongoDB Perl Driver v1.4.0. They are available for evaluation and testing
+and should not be used in production.
 
 =head1 SYNOPSIS
 
