@@ -20,11 +20,12 @@ package MongoDB::Database;
 # ABSTRACT: A MongoDB Database
 
 use version;
-our $VERSION = 'v1.1.1'; # TRIAL
+our $VERSION = 'v1.3.0'; # TRIAL
 
 use MongoDB::CommandResult;
 use MongoDB::Error;
 use MongoDB::GridFS;
+use MongoDB::GridFSBucket;
 use MongoDB::Op::_ListCollections;
 use MongoDB::ReadPreference;
 use MongoDB::_Query;
@@ -264,15 +265,49 @@ sub get_collection {
 
 { no warnings 'once'; *coll = \&get_collection }
 
-#pod =method get_gridfs
+#pod =method get_gridfsbucket
+#pod
+#pod     my $grid = $database->get_gridfsbucket;
+#pod     my $grid = $database->get_gridfsbucket($options);
+#pod
+#pod This method returns a L<MongoDB::GridFSBucket> object for storing and
+#pod retrieving files from the database.
+#pod
+#pod It takes an optional hash reference of options that are passed to the
+#pod L<MongoDB::GridFSBucket> constructor.
+#pod
+#pod See L<MongoDB::GridFSBucket> for more information.
+#pod
+#pod =cut
+
+sub get_gridfsbucket {
+    my ($self, $options) = @_;
+
+    return MongoDB::GridFSBucket->new(
+        read_preference => $self->read_preference,
+        write_concern   => $self->write_concern,
+        read_concern    => $self->read_concern,
+        bson_codec      => $self->bson_codec,
+        max_time_ms     => $self->max_time_ms,
+        ( $options ? %$options : () ),
+        # not allowed to be overridden by options
+        database => $self,
+    )
+}
+
+#pod =method get_gridfs (DEPRECATED)
 #pod
 #pod     my $grid = $database->get_gridfs;
 #pod     my $grid = $database->get_gridfs("fs");
 #pod     my $grid = $database->get_gridfs("fs", $options);
 #pod
-#pod Returns a L<MongoDB::GridFS> for storing and retrieving files from the database.
-#pod Default prefix is "fs", making C<$grid-E<gt>files> "fs.files" and C<$grid-E<gt>chunks>
-#pod "fs.chunks".
+#pod The L<MongoDB::GridFS> class has been deprecated in favor of the new MongoDB
+#pod driver-wide standard GridFS API, available via L<MongoDB::GridFSBucket> and
+#pod the C<get_gridfsbucket> method.
+#pod
+#pod This method returns a L<MongoDB::GridFS> for storing and retrieving files
+#pod from the database.  Default prefix is "fs", making C<$grid-E<gt>files>
+#pod "fs.files" and C<$grid-E<gt>chunks> "fs.chunks".
 #pod
 #pod It takes an optional hash reference of options that are passed to the
 #pod L<MongoDB::GridFS> constructor.
@@ -407,7 +442,7 @@ MongoDB::Database - A MongoDB Database
 
 =head1 VERSION
 
-version v1.1.1
+version v1.3.0
 
 =head1 SYNOPSIS
 
@@ -562,15 +597,32 @@ L<MongoDB::Collection> constructor.
 
 The C<coll> method is an alias for C<get_collection>.
 
-=head2 get_gridfs
+=head2 get_gridfsbucket
+
+    my $grid = $database->get_gridfsbucket;
+    my $grid = $database->get_gridfsbucket($options);
+
+This method returns a L<MongoDB::GridFSBucket> object for storing and
+retrieving files from the database.
+
+It takes an optional hash reference of options that are passed to the
+L<MongoDB::GridFSBucket> constructor.
+
+See L<MongoDB::GridFSBucket> for more information.
+
+=head2 get_gridfs (DEPRECATED)
 
     my $grid = $database->get_gridfs;
     my $grid = $database->get_gridfs("fs");
     my $grid = $database->get_gridfs("fs", $options);
 
-Returns a L<MongoDB::GridFS> for storing and retrieving files from the database.
-Default prefix is "fs", making C<$grid-E<gt>files> "fs.files" and C<$grid-E<gt>chunks>
-"fs.chunks".
+The L<MongoDB::GridFS> class has been deprecated in favor of the new MongoDB
+driver-wide standard GridFS API, available via L<MongoDB::GridFSBucket> and
+the C<get_gridfsbucket> method.
+
+This method returns a L<MongoDB::GridFS> for storing and retrieving files
+from the database.  Default prefix is "fs", making C<$grid-E<gt>files>
+"fs.files" and C<$grid-E<gt>chunks> "fs.chunks".
 
 It takes an optional hash reference of options that are passed to the
 L<MongoDB::GridFS> constructor.
