@@ -12,15 +12,13 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
-#
 
 package MongoDB::GridFS;
 
-
-# ABSTRACT: A file storage utility
+# ABSTRACT: A file storage abstraction (DEPRECATED)
 
 use version;
-our $VERSION = 'v1.1.1'; # TRIAL
+our $VERSION = 'v1.3.0'; # TRIAL
 
 use MongoDB::GridFS::File;
 use Digest::MD5;
@@ -472,11 +470,11 @@ __END__
 
 =head1 NAME
 
-MongoDB::GridFS - A file storage utility
+MongoDB::GridFS - A file storage abstraction (DEPRECATED)
 
 =head1 VERSION
 
-version v1.1.1
+version v1.3.0
 
 =head1 SYNOPSIS
 
@@ -673,6 +671,14 @@ Removes all files' metadata and contents.
 Returns a list of the files in the database as L<MongoDB::GridFS::File>
 objects.
 
+=head1 DEPRECATION
+
+B<Note>: This class has been deprecated in favor of
+L<MongoDB::GridFSBucket>, which implements the new, driver-standard GridFS
+API.  It is also faster and more flexible than this class.  This class will
+be removed in a future release and you are encouraged to migrate your
+applications to L<MongoDB::GridFSBucket>.
+
 =head1 SEE ALSO
 
 Core documentation on GridFS: L<http://dochub.mongodb.org/core/gridfs>.
