@@ -17,10 +17,10 @@
 package MongoDB::GridFS::File;
 
 
-# ABSTRACT: A Mongo GridFS file
+# ABSTRACT: A Mongo GridFS file (DEPRECATED)
 
 use version;
-our $VERSION = 'v1.1.1'; # TRIAL
+our $VERSION = 'v1.3.0'; # TRIAL
 
 use MongoDB::Error;
 use IO::File;
@@ -159,11 +159,11 @@ __END__
 
 =head1 NAME
 
-MongoDB::GridFS::File - A Mongo GridFS file
+MongoDB::GridFS::File - A Mongo GridFS file (DEPRECATED)
 
 =head1 VERSION
 
-version v1.1.1
+version v1.3.0
 
 =head1 SYNOPSIS
 
@@ -228,6 +228,13 @@ of bytes written.
 Return the number of bytes specified from the offset specified.  If no
 C<$length> or C<$offset> are given, the entire file is returned.
 
+=head1 DEPRECATION
+
+B<Note>: This class has been deprecated in favor of
+L<MongoDB::GridFSBucket> and its related upload and download classes.  This
+class will be removed in a future release and you are encouraged to migrate
+your applications to L<MongoDB::GridFSBucket>.
+
 =head1 AUTHORS
 
 =over 4
